# ensemble
While working on the Kaggle competition, [Optiver - Trading at the Close](https://github.com/whitgroves/optiver-trading-at-the-close), I developed some code that I want to repackage here.

This code was written against CUDA 12.2 and not tested on other versions. Compatability was a hassle, so run `cuda-venv.sh` to setup the virtual environment instead of using `conda` or `pip`.